#
# spec file for package sankore
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define         dest_dir %{_libdir}/OpenSankore
# OR %%{_datadir}/%%{name} ?
Name:		sankore
Version:	3.1.git.1373027794
Release:	22.1
License:	GPL-3.0+
Summary:	The open-source software suite for digital teachers
Url:		https://github.com/Sankore/
Group:		Amusements/Teaching/Other
Source0:	%{name}-%{version}.tar.xz
# Source1:	%%{name}-thirdparty-1353579018.tar.xz
Patch0:		tutorial_it.diff
Patch1:		editor_it.diff
# fix include in UBGraphicsItemAction.h
Patch2:         %{name}-phonon_include.patch
# use libs from openSUSE
Patch3:         %{name}-no_Third-Party.patch
# use poppler instead of xpdf to handle pdf
Patch4:         %{name}-XPDFRenderer_with_poppler.patch
# quazip from distro for plugins, too
Patch5:         %{name}-plugins_UBCFFAdaptor.diff

%if 0%{?suse_version}
BuildRequires:	libnotify-tools libgomp1
BuildRequires:	libQtWebKit-devel libqt4-devel
BuildRequires:	freetype2-devel
BuildRequires:	libpoppler-devel >= 0.20.0
%endif

%if 0%{?fedora}
BuildRequires:	libnotify libgomp
BuildRequires:	qtwebkit-devel qt-devel
BuildRequires:	openssl-devel
BuildRequires:	poppler-devel freetype-devel
%endif

BuildRequires:	quazip-devel
BuildRequires:	qtsingleapplication-devel
BuildRequires:	phonon-devel
BuildRequires:	libpaper-devel
BuildRequires:	t1lib-devel
BuildRequires:	flex bison
BuildRequires:	fdupes
BuildRequires:	desktop-file-utils

%if 0%{?suse_version} <= 1210
# Only needed for openSUSE <= 12.1; later it is pulled in by rpm-build.
BuildRequires:  xz
%endif

%description
%{name} can be considered as three integrated functions in one outstanding tool:
- uniboard universal interactive white board software
- the sankore teaching designer
- the sankore editor

Authors:
--------
http://open-sankore.org/
  
%prep
%setup -q

#Italian Tutorial
%patch0 -p1
#Italian Editor
%patch1 -p1

%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5

%if 0%{?suse_version}
  %define qmake qmake
  %define lrelease lrelease
%else
  %define qmake qmake-qt4
  %define lrelease lrelease-qt4
%endif

%build
# plugin cffadaptor (should be redundant, since code is already included into the main program while building)
pushd plugins/cffadaptor
%qmake UBCFFAdaptor.pro QMAKE_CFLAGS+="%optflags" QMAKE_CXXFLAGS+="%optflags"
%{__make} %{?_smp_mflags} VERBOSE=1
popd

%qmake Sankore_3.1.pro QMAKE_CFLAGS+="%optflags" QMAKE_CXXFLAGS+="%optflags"
%{__make} %{?_smp_mflags} VERBOSE=1

%install
%{__make} install

#missed icon, taking one
install -D -m 0644 resources/images/uniboard.png %{buildroot}%{_datadir}/pixmaps/sankore.png

#missed desktop file, writing one
mkdir -p %{buildroot}%{_datadir}/applications/
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Open-Sankore
GenericName=Open-Sankore
Comment=Software to create presentations for interactive whiteboard (TNI)
Comment[fr]=Logiciel de création de présentations pour tableau numérique interactif (TNI)
Exec=%{dest_dir}/run.sh
Icon=sankore
StartupNotify=true
Terminal=false
Type=Application
Categories=Qt;KDE;Education;Teaching;
X-SuSE-translate=false
EOF

#Install files
install -D -m 0755 build/linux/release/product/Open-Sankore %{buildroot}%dest_dir/Open-Sankore
cp -r build/linux/release/product/* %{buildroot}%{dest_dir}/

#run.sh (set env to avoid some possible issues)
cat > %{buildroot}%dest_dir/run.sh <<EOF
#!/bin/bash
# --------------------------------------------------------------------
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# ---------------------------------------------------------------------

env QT_PLUGIN_PATH=\$QT_PLUGIN_PATH:%{dest_dir}/OpenSankore/plugins LD_LIBRARY_PATH=\$LD_LIBRARY_PATH:%{dest_dir}/plugins/cffadaptor %dest_dir/Open-Sankore
EOF
chmod 0755 %{buildroot}%dest_dir/run.sh
mkdir -p %{buildroot}/%_bindir/
%__ln_s -T %{dest_dir}/run.sh %{buildroot}/%_bindir/open-%{name}

# clean some exe bits
find %{buildroot}%dest_dir/library -executable -type f -name *.js -exec chmod -x '{}' \+
find %{buildroot}%dest_dir/library -executable -type f -name *.svg -exec chmod -x '{}' \+
find %{buildroot}%dest_dir/library -executable -type f -name *.css -exec chmod -x '{}' \+
find %{buildroot}%dest_dir/library -executable -type f -name *.xml -exec chmod -x '{}' \+
chmod -x %{buildroot}%dest_dir/library/*/*/*.html

# internalization
%lrelease -removeidentical Sankore_3.1.pro
mkdir -p %{buildroot}%dest_dir/i18n/
cp -R resources/i18n/sankore*.qm %{buildroot}%dest_dir/i18n/

# Disabled, we added local_plugins to qt_plugins...
# ... otherwise we would brake icons and more (GUI/plugin translations?) and we would have
# to copy/link global qt4/plugins inside program dir
# # qt.conf
# cp -R resources/linux/qtlinux/* %%{buildroot}%%dest_dir/

# customizations
cp -R resources/customizations %{buildroot}%dest_dir/

# startup hints
cp -R resources/startupHints %{buildroot}%{dest_dir}/

# plugins
mkdir -p %{buildroot}%dest_dir/plugins/cffadaptor
install plugins/cffadaptor/build/linux/release/lib/libCFF_Adaptor* %{buildroot}%dest_dir/plugins/cffadaptor/

%if 0%{?suse_version}
%fdupes %{buildroot}%{dest_dir}
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc README.txt LICENSE.txt JournalDesModifications.pdf ReleaseNotes.pdf
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{dest_dir}/
%{_bindir}/open-%{name}

%changelog
* Sat May 11 2013 fa0sck@gmail.com
- Build to last git version
- Package specific:
  * patch to use openSUSE libraries instead of
    Third-Party
  * use libpoppler instead of xpdf
  * discard qt.conf and use Qt libs and plugins
    from system
* Sun Dec  9 2012 chri@gallochri.com
-Initial Debian Version
* Wed Dec  5 2012 chri@gallochri.com
-Moved files to /usr/lib(64)
* Mon Dec  3 2012 chri@gallochri.com
-Fedora_17 version added
* Mon Dec  3 2012 chri@gallochri.com
-First initial release
